**Example 1: 样例**

周期实例统计

Input: 

```
tccli wedata DescribeInstanceByCycle --cli-unfold-argument  \
    --ProjectId 1460947878944567296
```

Output: 
```
{
    "Response": {
        "Data": [
            {
                "Number": 445,
                "CycleUnit": "I",
                "ProjectId": "1460947878944567296"
            }
        ],
        "RequestId": "d197a658-411e-4d82-a3f6-35b11e5c9c44"
    }
}
```

